package
Version:
v0.13.2
Opens a new window with list of versions in this module.
Published: Mar 1, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package memtenantstore provides an in-memory implementation of driver.TenantStore.
New creates a new in-memory TenantStore.
Option configures a memtenantstore.
func WithMaxDestinationsPerTenant(max int) Option
WithMaxDestinationsPerTenant sets the max destinations per tenant.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.